==> qmmp-plugin-pack-0.9.5.tar.bz2: qmmp-plugin-pack-0.9.5/src/Input/ffap/translations/ffap_plugin_he.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he" version="2.0">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="48"/>
        <source>FFap Plugin</source>
        <translation>תוסף FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="50"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>קבצי Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>About FFap Audio Plugin</source>
        <translation>אודות תוסף שמע FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>תוסף שמע FFap של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="155"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>תוסף זה מספק תמיכה לקבצי Monkey&apos;s Audio ‏(APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="156"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>מבוסס על קוד מתוך deadbeef, FFmpeg וגם rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Input/ffap/translations/ffap_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="53"/>
        <source>FFap Plugin</source>
        <translation>תוסף FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="55"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>קבצי Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="163"/>
        <source>About FFap Audio Plugin</source>
        <translation>אודות תוסף שמע FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="164"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>תוסף שמע FFap של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="165"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>תוסף זה מספק תמיכה לקבצי Monkey&apos;s Audio ‏(APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="166"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="167"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>מבוסס על קוד מתוך deadbeef, FFmpeg וגם rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>
